@@ -1,11 +1,3 @@
-import hashlib
-from django.contrib.auth.models import User
-
-def username_from_session(session_key, username_length=None):
-    if not username_length:
-        username_length = User._meta.get_field('username').max_length
-    return hashlib.sha1(session_key).hexdigest()[:username_length]
-
 def is_lazy_user(user):
     """ Return True if the passed user is a lazy user. """
     # Anonymous users are not lazy.
@@ -20,4 +12,4 @@ def is_lazy_user(user):
 
     # Otherwise, we have to fall back to checking the database.
     from lazysignup.models import LazyUser
-    return bool(LazyUser.objects.filter(user=user).count() > 0)
\ No newline at end of file
+    return bool(LazyUser.objects.filter(user=user).count() > 0)
